from typing import Sequence, Optional

# from delvis.engine.verifier import VerificationEngine
# from delvis.models.base import AutoregressiveModel
# from delvis.constraints.base import Constraint
# from delvis.plugins.base import FrontierScorer


def verify(
    # model: AutoregressiveModel,
    # prompt: Sequence[str],
    # constraint: Constraint,
    # *,
    # budget: int = 10_000,
    # scorer: Optional[FrontierScorer] = None,
):
    """
    Deterministically verify a model against a constraint.

    Returns sound probability bounds and counterexamples.
    """
    # engine = VerificationEngine(
    #     model=model,
    #     constraint=constraint,
    #     scorer=scorer,
    # )
    # return engine.run(prompt=prompt, budget=budget)
    return "Not yet implemented."
